==> zio-aws-apigatewayv2_2.12-5.17.130.3-sources.jar: zio/aws/apigatewayv2/model/DeleteStageRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteStageRequest(apiId: __string, stageName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest = {
    import DeleteStageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .stageName(__string.unwrap(stageName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteStageRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteStageRequest.wrap(buildAwsValue())
}
object DeleteStageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteStageRequest =
      zio.aws.apigatewayv2.model.DeleteStageRequest(apiId, stageName)
    def apiId: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
  ) extends zio.aws.apigatewayv2.model.DeleteStageRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val stageName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.stageName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
  ): zio.aws.apigatewayv2.model.DeleteStageRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.12-5.17.239.4-sources.jar: zio/aws/apigatewayv2/model/DeleteStageRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteStageRequest(apiId: __string, stageName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest = {
    import DeleteStageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .stageName(stageName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteStageRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteStageRequest.wrap(buildAwsValue())
}
object DeleteStageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteStageRequest =
      zio.aws.apigatewayv2.model.DeleteStageRequest(apiId, stageName)
    def apiId: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
  ) extends zio.aws.apigatewayv2.model.DeleteStageRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val stageName: __string = impl.stageName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteStageRequest
  ): zio.aws.apigatewayv2.model.DeleteStageRequest.ReadOnly = new Wrapper(impl)
}
